package Data::Sah::Coerce::perl::duration::str_alami_id;

our $DATE = '2016-06-29'; # DATE
our $VERSION = '0.001'; # VERSION

use 5.010001;
use strict;
use warnings;

sub meta {
    +{
        v => 2,
        enable_by_default => 0,
        might_die => 1,
        prio => 60, # a bit lower than normal
        precludes => [qr/\Astr_alami(_.+)?\z/, 'str_human'],
    };
}

sub coerce {
    my %args = @_;

    my $dt = $args{data_term};
    my $coerce_to = $args{coerce_to} // 'float(secs)';

    my $res = {};

    $res->{expr_match} = "!ref($dt)";
    $res->{modules}{"DateTime::Format::Alami::ID"} //= 0;
    $res->{expr_coerce} = join(
        "",
        "do { my \$res = DateTime::Format::Alami::ID->new->parse_datetime_duration($dt, {format=>'combined'}) or die \"Can't coerce string '\".$dt.\"' to duration\"; ",
        ($coerce_to eq 'float(secs)' ? "\$res = \$res->{seconds}; " :
             $coerce_to eq 'DateTime::Duration' ? "\$res = \$res->{Duration}; " :
             (die "BUG: Unknown coerce_to '$coerce_to'")),
        "\$res }",
    );
    $res;
}

1;
# ABSTRACT: Coerce duration from string parsed by DateTime::Format::Alami::ID

__END__

=pod

=encoding UTF-8

=head1 NAME

Data::Sah::Coerce::perl::duration::str_alami_id - Coerce duration from string parsed by DateTime::Format::Alami::ID

=head1 VERSION

This document describes version 0.001 of Data::Sah::Coerce::perl::duration::str_alami_id (from Perl distribution Data-Sah-Coerce-perl-duration-str_alami_id), released on 2016-06-29.

=head1 DESCRIPTION

The rule is not enabled by default. You can enable it in a schema using e.g.:

 ["duration", "x.perl.coerce_rules"=>["str_alami_id"]]

=for Pod::Coverage ^(meta|coerce)$

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Data-Sah-Coerce-perl-duration-str_alami_id>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Data-Sah-Coerce-perl-duration-str_alami_id>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Sah-Coerce-perl-duration-str_alami_id>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
